==> open-xchange-appsuite-backend_7.8.1.orig.tar.bz2: open-xchange-appsuite-backend-7.8.1/com.openexchange.printing/src/com/openexchange/printing/contacts/ContactTemplateHelperFactory.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.printing.contacts;


import java.util.Collections;
import java.util.Map;
import java.util.TimeZone;
import com.openexchange.ajax.requesthandler.AJAXRequestData;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.ajax.requesthandler.Converter;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.ldap.User;
import com.openexchange.server.ServiceLookup;
import com.openexchange.templating.TemplateHelperFactory;
import com.openexchange.tools.servlet.AjaxExceptionCodes;
import com.openexchange.tools.session.ServerSession;

public class ContactTemplateHelperFactory implements TemplateHelperFactory {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ContactTemplateHelperFactory.class);

	private final ServiceLookup services;

    public ContactTemplateHelperFactory(ServiceLookup services) {
        this.services = services;
    }

	@Override
	public String getName() {
		return "contacts";
	}

	@Override
	public Object create(AJAXRequestData requestData, AJAXRequestResult result, ServerSession session, Converter converter, Map<String, Object> rootObject) throws OXException {
		try {
            User user = session.getUser();
            TimeZone tz = TimeZone.getTimeZone( requestData.isSet("timezone") ? requestData.getParameter("timezone") : user.getTimeZone() );
            final Map<String, Object> map;
            {
                final Object resultObject = result.getResultObject();
                if (!(resultObject instanceof Map)) {
                    map = Collections.emptyMap();
                    LOG.warn("{} is not a {}!", null == resultObject ? "null" : resultObject.getClass().getName(), Map.class.getName());
                } else {
                    @SuppressWarnings("unchecked")
                    Map<String, Object> tmp = (Map<String, Object>) resultObject;
                    map = tmp;
                }
            }
            return new ContactHelper(map, user.getLocale(), tz, session.getContext(), services);
        } catch (final RuntimeException e) {
            throw AjaxExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
        }
	}
}

==> open-xchange-appsuite-backend_7.10.1.orig.tar.bz2: open-xchange-appsuite-backend-7.10.1/com.openexchange.printing/src/com/openexchange/printing/contacts/ContactTemplateHelperFactory.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.printing.contacts;


import java.util.Collections;
import java.util.Map;
import java.util.TimeZone;
import com.openexchange.ajax.printing.TemplateHelperFactory;
import com.openexchange.ajax.requesthandler.AJAXRequestData;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.ajax.requesthandler.Converter;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.ldap.User;
import com.openexchange.server.ServiceLookup;
import com.openexchange.tools.servlet.AjaxExceptionCodes;
import com.openexchange.tools.session.ServerSession;

public class ContactTemplateHelperFactory implements TemplateHelperFactory {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ContactTemplateHelperFactory.class);

	private final ServiceLookup services;

    public ContactTemplateHelperFactory(ServiceLookup services) {
        this.services = services;
    }

	@Override
	public String getName() {
		return "contacts";
	}

	@Override
	public Object create(AJAXRequestData requestData, AJAXRequestResult result, ServerSession session, Converter converter, Map<String, Object> rootObject) throws OXException {
		try {
            User user = session.getUser();
            TimeZone tz = TimeZone.getTimeZone( requestData.isSet("timezone") ? requestData.getParameter("timezone") : user.getTimeZone() );
            final Map<String, Object> map;
            {
                final Object resultObject = result.getResultObject();
                if (!(resultObject instanceof Map)) {
                    map = Collections.emptyMap();
                    LOG.warn("{} is not a {}!", null == resultObject ? "null" : resultObject.getClass().getName(), Map.class.getName());
                } else {
                    @SuppressWarnings("unchecked")
                    Map<String, Object> tmp = (Map<String, Object>) resultObject;
                    map = tmp;
                }
            }
            return new ContactHelper(map, user.getLocale(), tz, session.getContext(), services);
        } catch (final RuntimeException e) {
            throw AjaxExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
        }
	}
}
